@@ -73,7 +73,7 @@ Hubzero_Document::addComponentStylesheet($this->option, 'assets/css/conditions.c
 		{ 
 			?>
 				<li<?php if (intval($this->filters['show']) == $query->id) { echo ' class="active"'; }?>>
-					<a class="common-<?php echo strtolower(preg_replace("/[^a-zA-Z0-9]/", '', stripslashes($query->title))); ?>" href="<?php echo JRoute::_('index.php?option=' . $this->option . '&controller=' . $this->controller . '&task=display&show=' . $query->id); ?>">
+					<a class="common-<?php echo strtolower(preg_replace("/[^a-zA-Z0-9]/", '', stripslashes($query->title))); ?>" href="<?php echo JRoute::_('index.php?option=' . $this->option . '&controller=' . $this->controller . '&task=display&show=' . $query->id . '&limitstart=0'); ?>">
 						<?php echo $this->escape(stripslashes($query->title)); ?> <span><?php echo $query->count; ?></span>
 					</a>
 					<a class="modal copy" href="<?php echo JRoute::_('index.php?option=' . $this->option . '&controller=queries&task=edit&id=' . $query->id); ?>" title="<?php echo JText::_('Edit'); ?>" rel="{handler: 'iframe', size: {x: 570, y: 550}}">
@@ -83,9 +83,12 @@ Hubzero_Document::addComponentStylesheet($this->option, 'assets/css/conditions.c
 					<ul class="views">
 				<?php } ?>
 				<?php if ($i == 2) { ?>
+						</li>
 					</ul>
-				<?php } ?>
 				</li>
+				<?php } else if ($i > 2) { ?>
+				</li>
+				<?php } ?>
 			<?php 
 			$i++;
 		} 
@@ -102,12 +105,14 @@ Hubzero_Document::addComponentStylesheet($this->option, 'assets/css/conditions.c
 	<?php if (count($this->queries['mine']) > 0) { ?>
 		<?php foreach ($this->queries['mine'] as $query) { ?>
 				<li<?php if (intval($this->filters['show']) == $query->id) { echo ' class="active"'; }?>>
-					<a class="my-<?php echo strtolower(preg_replace("/[^a-zA-Z0-9]/", '', stripslashes($query->title))); ?>" href="<?php echo JRoute::_('index.php?option=' . $this->option . '&controller=' . $this->controller . '&task=display&show=' . $query->id); ?>">
+					<a class="my-<?php echo strtolower(preg_replace("/[^a-zA-Z0-9]/", '', stripslashes($query->title))); ?>" href="<?php echo JRoute::_('index.php?option=' . $this->option . '&controller=' . $this->controller . '&task=display&show=' . $query->id . '&limitstart=0'); ?>">
 						<?php echo $this->escape(stripslashes($query->title)); ?> <span><?php echo $query->count; ?></span>
 					</a>
+				<?php if ($this->acl->check('read', 'tickets')) { ?>
 					<a class="modal copy" href="<?php echo JRoute::_('index.php?option=' . $this->option . '&controller=queries&task=edit&id=' . $query->id); ?>" title="<?php echo JText::_('Edit'); ?>" rel="{handler: 'iframe', size: {x: 570, y: 550}}">
 						<?php echo JText::_('Edit'); ?>
 					</a>
+				<?php } ?>
 				</li>
 		<?php } ?>
 	<?php } else { ?>
@@ -122,7 +127,7 @@ Hubzero_Document::addComponentStylesheet($this->option, 'assets/css/conditions.c
 	<?php if (count($this->queries['custom']) > 0) { ?>
 		<?php foreach ($this->queries['custom'] as $query) { ?>
 				<li<?php if (intval($this->filters['show']) == $query->id) { echo ' class="active"'; }?>>
-					<a href="<?php echo JRoute::_('index.php?option=' . $this->option . '&controller=' . $this->controller . '&task=display&show=' . $query->id); ?>">
+					<a href="<?php echo JRoute::_('index.php?option=' . $this->option . '&controller=' . $this->controller . '&task=display&show=' . $query->id . '&limitstart=0'); ?>">
 						<?php echo $this->escape(stripslashes($query->title)); ?> <span><?php echo $query->count; ?></span>
 					</a>
 					<a class="delete" href="<?php echo JRoute::_('index.php?option=' . $this->option . '&controller=queries&task=remove&id=' . $query->id); ?>" title="<?php echo JText::_('Delete'); ?>">
@@ -158,32 +163,32 @@ Hubzero_Document::addComponentStylesheet($this->option, 'assets/css/conditions.c
 						</th>
 						<th scope="col">
 							<?php $direction = (strtolower($this->filters['sortdir']) == 'desc') ? 'asc' : 'desc'; ?>
-							<a class="sort-age<?php if ($this->filters['sort'] == 'created') { echo ' active ' . strtolower($this->filters['sortdir']); } ?>" href="<?php echo JRoute::_('index.php?option=' . $this->option . '&controller=' . $this->controller . '&task=display&show=' . $this->filters['show'] . '&search=' . $this->filters['search'] . '&sort=created&sortdir=' . $direction . '&limit=' . $this->filters['limit'] . '&limitstart=' . $this->filters['start']); ?>" title="Click to sort by this column">
+							<a class="sort-age<?php if ($this->filters['sort'] == 'created') { echo ' active ' . strtolower($this->filters['sortdir']); } ?>" href="<?php echo JRoute::_('index.php?option=' . $this->option . '&controller=' . $this->controller . '&task=display&show=' . $this->filters['show'] . '&search=' . $this->filters['search'] . '&sort=created&sortdir=' . $direction . '&limit=' . $this->filters['limit'] . '&limitstart=0'); ?>" title="Click to sort by this column">
 								<?php echo JText::_('SUPPORT_COL_AGE'); ?>
 							</a>
 						</th>
 						<th scope="col">
-							<a class="sort-status<?php if ($this->filters['sort'] == 'status') { echo ' active ' . strtolower($this->filters['sortdir']); } ?>" href="<?php echo JRoute::_('index.php?option=' . $this->option . '&controller=' . $this->controller . '&task=display&show=' . $this->filters['show'] . '&search=' . $this->filters['search'] . '&sort=status&sortdir=' . $direction . '&limit=' . $this->filters['limit'] . '&limitstart=' . $this->filters['start']); ?>" title="Click to sort by this column">
+							<a class="sort-status<?php if ($this->filters['sort'] == 'status') { echo ' active ' . strtolower($this->filters['sortdir']); } ?>" href="<?php echo JRoute::_('index.php?option=' . $this->option . '&controller=' . $this->controller . '&task=display&show=' . $this->filters['show'] . '&search=' . $this->filters['search'] . '&sort=status&sortdir=' . $direction . '&limit=' . $this->filters['limit'] . '&limitstart=0'); ?>" title="Click to sort by this column">
 								<?php echo JText::_('SUPPORT_COL_STATUS'); ?>
 							</a>
 						</th>
 						<th scope="col">
-							<a class="sort-severity<?php if ($this->filters['sort'] == 'severity') { echo ' active ' . strtolower($this->filters['sortdir']); } ?>" href="<?php echo JRoute::_('index.php?option=' . $this->option . '&controller=' . $this->controller . '&task=display&show=' . $this->filters['show'] . '&search=' . $this->filters['search'] . '&sort=severity&sortdir=' . $direction . '&limit=' . $this->filters['limit'] . '&limitstart=' . $this->filters['start']); ?>" title="Click to sort by this column">
+							<a class="sort-severity<?php if ($this->filters['sort'] == 'severity') { echo ' active ' . strtolower($this->filters['sortdir']); } ?>" href="<?php echo JRoute::_('index.php?option=' . $this->option . '&controller=' . $this->controller . '&task=display&show=' . $this->filters['show'] . '&search=' . $this->filters['search'] . '&sort=severity&sortdir=' . $direction . '&limit=' . $this->filters['limit'] . '&limitstart=0'); ?>" title="Click to sort by this column">
 								<?php echo JText::_('SUPPORT_COL_SEVERITY'); ?>
 							</a>
 						</th>
 						<th scope="col">
-							<a class="sort-summary<?php if ($this->filters['sort'] == 'summary') { echo ' active ' . strtolower($this->filters['sortdir']); } ?>" href="<?php echo JRoute::_('index.php?option=' . $this->option . '&controller=' . $this->controller . '&task=display&show=' . $this->filters['show'] . '&search=' . $this->filters['search'] . '&sort=summary&sortdir=' . $direction . '&limit=' . $this->filters['limit'] . '&limitstart=' . $this->filters['start']); ?>" title="Click to sort by this column">
+							<a class="sort-summary<?php if ($this->filters['sort'] == 'summary') { echo ' active ' . strtolower($this->filters['sortdir']); } ?>" href="<?php echo JRoute::_('index.php?option=' . $this->option . '&controller=' . $this->controller . '&task=display&show=' . $this->filters['show'] . '&search=' . $this->filters['search'] . '&sort=summary&sortdir=' . $direction . '&limit=' . $this->filters['limit'] . '&limitstart=0'); ?>" title="Click to sort by this column">
 								<?php echo JText::_('SUPPORT_COL_SUMMARY'); ?>
 							</a>
 						</th>
 						<th scope="col">
-							<a class="sort-group<?php if ($this->filters['sort'] == 'group') { echo ' active ' . strtolower($this->filters['sortdir']); } ?>" href="<?php echo JRoute::_('index.php?option=' . $this->option . '&controller=' . $this->controller . '&task=display&show=' . $this->filters['show'] . '&search=' . $this->filters['search'] . '&sort=group&sortdir=' . $direction . '&limit=' . $this->filters['limit'] . '&limitstart=' . $this->filters['start']); ?>" title="Click to sort by this column">
+							<a class="sort-group<?php if ($this->filters['sort'] == 'group') { echo ' active ' . strtolower($this->filters['sortdir']); } ?>" href="<?php echo JRoute::_('index.php?option=' . $this->option . '&controller=' . $this->controller . '&task=display&show=' . $this->filters['show'] . '&search=' . $this->filters['search'] . '&sort=group&sortdir=' . $direction . '&limit=' . $this->filters['limit'] . '&limitstart=0'); ?>" title="Click to sort by this column">
 								<?php echo JText::_('SUPPORT_COL_GROUP'); ?>
 							</a>
 						</th>
 						<th scope="col">
-							<a class="sort-owner<?php if ($this->filters['sort'] == 'owner') { echo ' active ' . strtolower($this->filters['sortdir']); } ?>" href="<?php echo JRoute::_('index.php?option=' . $this->option . '&controller=' . $this->controller . '&task=display&show=' . $this->filters['show'] . '&search=' . $this->filters['search'] . '&sort=owner&sortdir=' . $direction . '&limit=' . $this->filters['limit'] . '&limitstart=' . $this->filters['start']); ?>" title="Click to sort by this column">
+							<a class="sort-owner<?php if ($this->filters['sort'] == 'owner') { echo ' active ' . strtolower($this->filters['sortdir']); } ?>" href="<?php echo JRoute::_('index.php?option=' . $this->option . '&controller=' . $this->controller . '&task=display&show=' . $this->filters['show'] . '&search=' . $this->filters['search'] . '&sort=owner&sortdir=' . $direction . '&limit=' . $this->filters['limit'] . '&limitstart=0'); ?>" title="Click to sort by this column">
 								<?php echo JText::_('SUPPORT_COL_OWNER'); ?>
 							</a>
 						</th>
@@ -229,6 +234,8 @@ if (count($ids))
 
 $users = array();
 
+$cls = 'even';
+
 ximport('Hubzero_View_Helper_Html');
 for ($i=0, $n=count($this->rows); $i < $n; $i++)
 {
@@ -279,7 +286,7 @@ for ($i=0, $n=count($this->rows); $i < $n; $i++)
 		{
 			//echo 'ffff';
 			$targetuser =& JUser::getInstance($row->login);
-			if ($targetuser->get('id'))
+			if (is_object($targetuser) && $targetuser->get('id'))
 			{
 				$users[$row->login] = $targetuser;
 				$lnk = JRoute::_('index.php?option=com_members&id=' . $targetuser->get('id'));
@@ -300,6 +307,10 @@ for ($i=0, $n=count($this->rows); $i < $n; $i++)
 	{
 		$row->summary .= '...';
 	}
+	if (!trim($row->summary))
+	{
+		$row->summary = JText::_('(no content found)');
+	}
 
 	$tags = '';
 	if (isset($alltags[$row->id]))
@@ -307,12 +318,12 @@ for ($i=0, $n=count($this->rows); $i < $n; $i++)
 		$tags = $st->get_tag_cloud(3, 1, $row->id);
 	}
 ?>
-					<tr>
+					<tr class="<?php echo $cls == 'odd' ? 'even' : 'odd'; ?>">
 						<td>
 							<span class="ticket-id">
 								<?php echo $row->id; ?>
 							</span>
-							<span class="<?php echo $status; ?> status hasTip" title="<?php echo JText::_('Details'); ?>::<?php echo '<strong>' . JText::_('SUPPORT_COL_STATUS') . ':</strong> ' . $status; echo ($row->open == 0) ? ' (' . $this->escape($row->resolved) . ')' : ''; echo '<br /><strong>' . JText::_('Priority') . ':</strong> ' . $this->escape($row->severity); ?>">
+							<span class="<?php echo $status; ?> status hasTip" title="<?php echo JText::_('Details'); ?> :: <?php echo '<strong>' . JText::_('SUPPORT_COL_STATUS') . ':</strong> ' . $status; echo ($row->open == 0) ? ' (' . $this->escape($row->resolved) . ')' : ''; ?>">
 								<?php echo $status; echo ($row->open == 0) ? ' (' . $this->escape($row->resolved) . ')' : ''; ?>
 							</span>
 						</td>
@@ -331,8 +342,8 @@ for ($i=0, $n=count($this->rows); $i < $n; $i++)
 		<?php } ?>
 							</p>
 							<p>
-								<a class="ticket-content" href="<?php echo JRoute::_('index.php?option=' . $this->option . '&controller=' . $this->controller . '&task=ticket&id=' . $row->id . '&show=' . $this->filters['show'] . '&search=' . $this->filters['search'] . '&limit=' . $this->filters['limit'] . '&limitstart=' . $this->filters['start']); ?>">
-									<?php echo stripslashes($row->summary); ?>
+								<a class="ticket-content" title="<?php echo $this->escape(stripslashes($row->report)); ?>" href="<?php echo JRoute::_('index.php?option=' . $this->option . '&controller=' . $this->controller . '&task=ticket&id=' . $row->id . '&show=' . $this->filters['show'] . '&search=' . $this->filters['search'] . '&limit=' . $this->filters['limit'] . '&limitstart=' . $this->filters['start']); ?>">
+									<?php echo $this->escape(stripslashes($row->summary)); ?>
 								</a>
 							</p>
 		<?php if ($tags || $row->owner) { ?>
@@ -342,10 +353,20 @@ for ($i=0, $n=count($this->rows); $i < $n; $i++)
 									<?php echo $tags; ?>
 								</span>
 		<?php } ?>
-		<?php if ($row->group) { ?>
-								<span class="ticket-group">
-									<?php echo $this->escape(stripslashes($row->group)); ?>
-								</span>
+		<?php if ($row->group) { 
+			if($this->acl->check('read', 'tickets'))
+			{
+				$queryid = $this->queries['common'][0]->id;
+			}
+			else
+			{
+				$queryid = $this->queries['mine'][0]->id;
+			}
+			$group = '<a href="' . JRoute::_('index.php?option='.$this->option.'&controller='.$this->controller.'&task=display&show='.$queryid.'&find='.urlencode('group:'.$this->escape(stripslashes($row->group)))).'">' . $this->escape(stripslashes($row->group)) . '</a>';
+		?>
+						<span class="ticket-group">
+							<?php echo $group; ?>
+						</span>
 		<?php } ?>
 		<?php if ($row->owner) { 
 					$owner = Hubzero_User_Profile::getInstance($row->owner);
@@ -360,7 +381,7 @@ for ($i=0, $n=count($this->rows); $i < $n; $i++)
 						</td>
 						<td class="tkt-severity">
 <?php if ($this->acl->check('delete', 'tickets')) { ?>
-							<span class="ticket-severity <?php echo $this->escape($row->severity); ?>">
+							<span class="ticket-severity <?php echo $this->escape($row->severity); ?> hasTip" title="<strong><?php echo JText::_('Priority'); ?>:</strong>&nbsp;<?php echo $this->escape($row->severity); ?>">
 								<span><?php echo $this->escape($row->severity); ?></span>
 							</span>
 							<a class="delete" href="<?php echo JRoute::_('index.php?option=' . $this->option . '&controller=' . $this->controller . '&task=delete&id=' . $row->id); ?>" title="<?php echo JText::_('SUPPORT_DELETE'); ?>">
