@@ -163,7 +163,7 @@ $txt['html'] = '<p>Embed an image in wiki-formatted text. The first argument is
 
 		// Get single attributes
 		// EX: [[Image(myimage.png, nolink, right)]]
-		$argues = preg_replace_callback('/[, ](left|right|top|bottom)(?:[, ]|$)/i', array(&$this, 'parseSingleAttribute'), $content);
+		$argues = preg_replace_callback('/[, ](left|right|top|center|bottom|[0-9]+(px|%|em)?)(?:[, ]|$)/i', array(&$this, 'parseSingleAttribute'), $content);
 		// Get quoted attribute/value pairs
 		// EX: [[Image(myimage.png, desc="My description, contains, commas")]]
 		$argues = preg_replace_callback('/[, ](alt|altimage|desc|title|width|height|align|border|longdesc|class|id|usemap)=(?:["\'])([^"]*)(?:["\'])/i', array(&$this, 'parseAttributeValuePair'), $content);
@@ -200,7 +200,7 @@ $txt['html'] = '<p>Embed an image in wiki-formatted text. The first argument is
 				$attr['desc'] = (isset($attr['desc'])) ? $attr['desc'] : '';
 				if (!$attr['desc'])
 				{
-					$attr['desc'] = ($attach->description) ? stripslashes($attach->description) : $attach->filename;
+					$attr['desc'] = ($attach->description) ? stripslashes($attach->description) : ''; //$attach->filename;
 				}
 
 				$ret = true;
@@ -209,7 +209,7 @@ $txt['html'] = '<p>Embed an image in wiki-formatted text. The first argument is
 		// Check for file existence
 		else if (file_exists($this->_path($file)) || file_exists($this->_path($file, true))) 
 		{
-			$attr['desc'] = (isset($attr['desc'])) ? $attr['desc'] : $file;
+			$attr['desc'] = (isset($attr['desc'])) ? $attr['desc'] : ''; //$file;
 
 			$ret = true;
 		} 
@@ -293,16 +293,25 @@ $txt['html'] = '<p>Embed an image in wiki-formatted text. The first argument is
 		}
 		// Check for alignment, no key given
 		// e.g., [[File(myfile.jpg, left)]]
-		if (in_array($key, array('left', 'right', 'top', 'bottom'))) 
+		if (in_array($key, array('left', 'right', 'top', 'bottom', 'center'))) 
 		{
-			$this->attr['style']['float'] = $key;
-			if ($key == 'left')
+			if ($key == 'center')
 			{
-				$this->attr['style']['margin-right'] = '1em';
+				$this->attr['style']['display'] = 'block';
+				$this->attr['style']['margin-right'] = 'auto';
+				$this->attr['style']['margin-left'] = 'auto';
 			}
-			else if ($key == 'right')
+			else 
 			{
-				$this->attr['style']['margin-left'] = '1em';
+				$this->attr['style']['float'] = $key;
+				if ($key == 'left')
+				{
+					$this->attr['style']['margin-right'] = '1em';
+				}
+				else if ($key == 'right')
+				{
+					$this->attr['style']['margin-left'] = '1em';
+				}
 			}
 			return;
 		}
@@ -319,6 +328,14 @@ $txt['html'] = '<p>Embed an image in wiki-formatted text. The first argument is
 			else 
 			{
 				$this->attr['style']['float'] = $val;
+				if ($val == 'left')
+				{
+					$this->attr['style']['margin-right'] = '1em';
+				}
+				else if ($val == 'right')
+				{
+					$this->attr['style']['margin-left'] = '1em';
+				}
 			}
 		} 
 		else if ($key == 'border') 
@@ -372,17 +389,26 @@ $txt['html'] = '<p>Embed an image in wiki-formatted text. The first argument is
 
 		// Check for alignment, no key given
 		// e.g., [[File(myfile.jpg, left)]]
-		if (in_array($key, array('left', 'right', 'top', 'bottom'))) 
+		if (in_array($key, array('left', 'right', 'top', 'bottom', 'center'))) 
 		{
-			$this->attr['style']['display'] = 'block';
-			$this->attr['style']['float'] = $key;
-			if ($key == 'left')
+			if ($key == 'center')
 			{
-				$this->attr['style']['margin-right'] = '1em';
+				$this->attr['style']['display'] = 'block';
+				$this->attr['style']['margin-right'] = 'auto';
+				$this->attr['style']['margin-left'] = 'auto';
 			}
-			else if ($key == 'right')
+			else 
 			{
-				$this->attr['style']['margin-left'] = '1em';
+				$this->attr['style']['display'] = 'block';
+				$this->attr['style']['float'] = $key;
+				if ($key == 'left')
+				{
+					$this->attr['style']['margin-right'] = '1em';
+				}
+				else if ($key == 'right')
+				{
+					$this->attr['style']['margin-left'] = '1em';
+				}
 			}
 			return;
 		}
